==> qcad_1.3.3.orig.tar.gz: qcad-1.3.3.orig/rlayoutdef.h <==
/***************************************************************************
                          rlayoutdef.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

// Graphic defines:
//

#ifndef RLAYOUTDEF_H
#define RLAYOUTDEF_H

#define DEF_BSIZE0             22
#define DEF_BSIZE1             22
#define DEF_BSIZE2             30

#define DEF_MBORDER0           2

#define DEF_BX1                2
#define DEF_BX2                (DEF_BX1+DEF_BSIZE2+DEF_MBORDER0)

#define DEF_BY1                2
#define DEF_BY2                (2+1*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY3                (2+2*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY4                (2+3*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY5                (2+4*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY6                (2+5*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY7                (2+6*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY8                (2+7*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY9                (2+8*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY10               (2+9*(DEF_BSIZE2+DEF_MBORDER0))

#define DEF_MINLAYERLISTWIDTH  75
#define DEF_MAXLAYERLISTWIDTH  75
#define DEF_INFOHEIGHT        110
#define DEF_MINAPPWIDTH       650
#define DEF_MINAPPHEIGHT      400
#define DEF_MINCAMDLGWIDTH    655
#define DEF_MINCAMDLGHEIGHT   430
#define DEF_MINFONTDLGWIDTH   500
#define DEF_MINFONTDLGHEIGHT  420
#define DEF_PANELHEIGHT        (DEF_BSIZE0+4)

#endif

// EOF

==> qcad_1.4.7.orig.tar.gz: qcad-1.4.7.orig/rlayoutdef.h <==
/***************************************************************************
                          rlayoutdef.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

// Graphic defines:
//

#ifndef RLAYOUTDEF_H
#define RLAYOUTDEF_H

#define DEF_BSIZE0             22
#define DEF_BSIZE1             22
#define DEF_BSIZE2             30

#define DEF_MBORDER0           2

#define DEF_BX1                2
#define DEF_BX2                (DEF_BX1+DEF_BSIZE2+DEF_MBORDER0)

#define DEF_BY1                2
#define DEF_BY2                (2+1*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY3                (2+2*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY4                (2+3*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY5                (2+4*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY6                (2+5*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY7                (2+6*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY8                (2+7*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY9                (2+8*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY10               (2+9*(DEF_BSIZE2+DEF_MBORDER0))
#define DEF_BY11               (2+10*(DEF_BSIZE2+DEF_MBORDER0))

#define DEF_MINLAYERLISTWIDTH  ((4+(6*DEF_BSIZE0))+16)
#define DEF_MAXLAYERLISTWIDTH  DEF_MINLAYERLISTWIDTH
#define DEF_INFOHEIGHT        110
#define DEF_MINAPPWIDTH       694
#define DEF_MINAPPHEIGHT      440
#define DEF_MINCAMDLGWIDTH    685
#define DEF_MINCAMDLGHEIGHT   430
#define DEF_MINFONTDLGWIDTH   500
#define DEF_MINFONTDLGHEIGHT  430
#define DEF_PANELHEIGHT       (DEF_BSIZE0+4)
#define DEF_STATUSBARHEIGHT   48


#endif

// EOF
